about summary refs log tree commit diff
path: root/pkgs/development/idris-modules/build-builtin-package.nix
diff options
context:
space:
mode:
authorFelix Buehler <account@buehler.rocks>2022-02-14 23:08:24 +0100
committerFelix Buehler <account@buehler.rocks>2022-02-23 11:28:15 +0100
commit3df56ed3e442d21aec6660775eacb7cb223dda25 (patch)
treeefee4873dea226b51beafda5174549e0f11cf705 /pkgs/development/idris-modules/build-builtin-package.nix
parent23e6a169722f7c514a6a5c6a7d1e6d0fb1408697 (diff)
downloadnixlib-3df56ed3e442d21aec6660775eacb7cb223dda25.tar
nixlib-3df56ed3e442d21aec6660775eacb7cb223dda25.tar.gz
nixlib-3df56ed3e442d21aec6660775eacb7cb223dda25.tar.bz2
nixlib-3df56ed3e442d21aec6660775eacb7cb223dda25.tar.lz
nixlib-3df56ed3e442d21aec6660775eacb7cb223dda25.tar.xz
nixlib-3df56ed3e442d21aec6660775eacb7cb223dda25.tar.zst
nixlib-3df56ed3e442d21aec6660775eacb7cb223dda25.zip
idris-modules: rename name to pname
Diffstat (limited to 'pkgs/development/idris-modules/build-builtin-package.nix')
-rw-r--r--pkgs/development/idris-modules/build-builtin-package.nix10
1 files changed, 5 insertions, 5 deletions
diff --git a/pkgs/development/idris-modules/build-builtin-package.nix b/pkgs/development/idris-modules/build-builtin-package.nix
index ff19e52135c8..fe23728e0848 100644
--- a/pkgs/development/idris-modules/build-builtin-package.nix
+++ b/pkgs/development/idris-modules/build-builtin-package.nix
@@ -1,13 +1,13 @@
 # Build one of the packages that comes with idris
 # name: The name of the package
 # deps: The dependencies of the package
-{ idris, build-idris-package }: name: deps:
+{ idris, build-idris-package }: pname: deps:
 let
   inherit (builtins.parseDrvName idris.name) version;
 in
 build-idris-package {
 
-  inherit name version;
+  inherit pname version;
   inherit (idris) src;
 
   noPrelude = true;
@@ -16,10 +16,10 @@ build-idris-package {
   idrisDeps = deps;
 
   postUnpack = ''
-    sourceRoot=$sourceRoot/libs/${name}
+    sourceRoot=$sourceRoot/libs/${pname}
   '';
 
   meta = idris.meta // {
-    description = "${name} builtin Idris library";
+    description = "${pname} builtin Idris library";
   };
 }
@@ -1,13 +1,13 @@
 # Build one of the packages that comes with idris
-# name: The name of the package
+# pname: The pname of the package
 # deps: The dependencies of the package